Index: applications/editors/josm/plugins/piclayer/src/org/openstreetmap/josm/plugins/piclayer/layer/PicLayerAbstract.java
===================================================================
--- applications/editors/josm/plugins/piclayer/src/org/openstreetmap/josm/plugins/piclayer/layer/PicLayerAbstract.java	(revision 27191)
+++ applications/editors/josm/plugins/piclayer/src/org/openstreetmap/josm/plugins/piclayer/layer/PicLayerAbstract.java	(revision 27220)
@@ -77,8 +77,8 @@
     private Icon layerIcon = null;
 
-    private boolean drawPoints = true;
+    private boolean drawMarkers = true;
 
     public void setDrawPoints(boolean value) {
-        drawPoints = value;
+        drawMarkers = value;
     }
 
@@ -122,5 +122,5 @@
         if (pinImage == null) {
             // allow system to load the image and use it in future
-            pinImage = new ImageIcon(Toolkit.getDefaultToolkit().createImage(getClass().getResource("/images/arrow.png"))).getImage();
+            pinImage = new ImageIcon(Toolkit.getDefaultToolkit().createImage(getClass().getResource("/images/marker.png"))).getImage();
         }
     }
@@ -245,6 +245,6 @@
                 );
             }
-            if (drawPoints ) {
-                // draw points for selection
+            if (drawMarkers ) {
+                // draw markers for selection
                 Graphics2D gPoints = (Graphics2D)g2.create();
 
@@ -259,6 +259,6 @@
                    Point2D trP = tr.transform(p, null);
                    int x = (int)trP.getX(), y = (int)trP.getY();
-                   gPoints.drawOval(x-2, y-2, 5, 5);
-                   gPoints.drawImage(pinImage, x, y, null);
+                   //gPoints.drawOval(x-2, y-2, 5, 5);
+                   gPoints.drawImage(pinImage, x-15, y-15, null);
                 }
             }
